@@ -1,6 +1,8 @@
 from django.utils.translation import ugettext_lazy as _
 from django.contrib import admin
 
+from authentic2.decorators import to_iter
+from authentic2.attributes_ng.engine import get_attribute_names
 from provider.oauth2.admin import ClientAdmin
 
 from . import models
@@ -11,6 +13,11 @@ class WebServiceAdmin(admin.ModelAdmin):
 class AttributeReleaseInline(admin.TabularInline):
     model = models.AttributeRelease
 
+    def formfield_for_choice_field(self, db_field, request, **kwargs):
+        if db_field.name == 'attribute_name':
+            kwargs['choices'] = to_iter(get_attribute_names)({'user': None, 'request': None})
+        return super(AttributeReleaseInline, self).formfield_for_choice_field(db_field, request, **kwargs)
+
 class A2ClientAdmin(ClientAdmin):
     inlines = [AttributeReleaseInline]
     fieldsets = (
